@@ -68,6 +68,8 @@ class System:
 
     def get(self):
         """"""
+        if not web.tx.user.is_owner:
+            return "owner only"
         ip_address = subprocess.check_output(["hostname", "-I"]).split()[0].decode()
         try:
             with open("/home/gaea/app/run/onion") as fp:
